# SPOK

[![PyPI](https://img.shields.io/pypi/v/spok)](https://pypi.python.org/pypi/spok)
[![Tests](https://github.com/LaboratoryOfPlasmaPhysics/spok/actions/workflows/test_main.yml/badge.svg)](https://github.com/LaboratoryOfPlasmaPhysics/spok/actions/workflows/test_main.yml)
[![Documentation Status](https://readthedocs.org/projects/spok/badge/?version=latest)](https://spok.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://codecov.io/gh/LaboratoryOfPlasmaPhysics/spok/branch/main/graph/badge.svg?branch=main)](https://codecov.io/gh/LaboratoryOfPlasmaPhysics/spok/branch/main)

spok Plasma Observations Kit

![spok](https://user-images.githubusercontent.com/3200931/98716891-978e2180-238c-11eb-9487-07c66221e5bb.png)


* Free software: GNU General Public License v3
* Documentation: https://spok.readthedocs.io.


## Features


## TODO

